@@ -27,7 +27,7 @@ module Cucumber
     # This will store <tt>[['a', 'b'], ['c', 'd']]</tt> in the <tt>data</tt> variable.
     #
     class DataTable
-      def self.default_arg_name # :nodoc:
+      def self.default_arg_name
         'table'
       end
 
@@ -75,7 +75,9 @@ module Cucumber
         def eof; end
       end
 
-      NULL_CONVERSIONS = Hash.new(strict: false, proc: ->(cell_value) { cell_value }).freeze
+      # This is a Hash being initialized with a default value of a Hash, DO NOT REFORMAT TO REMOVE {}
+      # Future versions [3.4.0+] of ruby will interpret these as keywords and break.
+      NULL_CONVERSIONS = Hash.new({ strict: false, proc: ->(cell_value) { cell_value } }).freeze
 
       # @param data [Core::Test::DataTable] the data for the table
       # @param conversion_procs [Hash] see map_column
@@ -194,17 +196,17 @@ module Cucumber
         end
       end
 
-      def column_names # :nodoc:
+      def column_names
         @column_names ||= cell_matrix[0].map(&:value)
       end
 
       def rows
         hashes.map do |hash|
-          hash.values_at *headers
+          hash.values_at(*headers)
         end
       end
 
-      def each_cells_row(&proc) # :nodoc:
+      def each_cells_row(&proc)
         cells_rows.each(&proc)
       end
 
@@ -340,7 +342,7 @@ module Cucumber
         cells_rows.map { |cells| cells.map(&:value) }
       end
 
-      def cells_to_hash(cells) # :nodoc:
+      def cells_to_hash(cells)
         hash = Hash.new do |hash_inner, key|
           hash_inner[key.to_s] if key.is_a?(Symbol)
         end
@@ -350,51 +352,51 @@ module Cucumber
         hash
       end
 
-      def index(cells) # :nodoc:
+      def index(cells)
         cells_rows.index(cells)
       end
 
-      def verify_column(column_name) # :nodoc:
+      def verify_column(column_name)
         raise %(The column named "#{column_name}" does not exist) unless raw[0].include?(column_name)
       end
 
-      def verify_table_width(width) # :nodoc:
+      def verify_table_width(width)
         raise %(The table must have exactly #{width} columns) unless raw[0].size == width
       end
 
       # TODO: remove the below function if it's not actually being used.
       # Nothing else in this repo calls it.
-      def text?(text) # :nodoc:
+      def text?(text)
         raw.flatten.compact.detect { |cell_value| cell_value.index(text) }
       end
 
-      def cells_rows # :nodoc:
-        @rows ||= cell_matrix.map do |cell_row| # rubocop:disable Naming/MemoizedInstanceVariableName
+      def cells_rows
+        @rows ||= cell_matrix.map do |cell_row|
           Cells.new(self, cell_row)
         end
       end
 
-      def headers # :nodoc:
+      def headers
         raw.first
       end
 
-      def header_cell(col) # :nodoc:
+      def header_cell(col)
         cells_rows[0][col]
       end
 
       attr_reader :cell_matrix
 
-      def col_width(col) # :nodoc:
+      def col_width(col)
         columns[col].__send__(:width)
       end
 
-      def to_s(options = {}) # :nodoc:
+      def to_s(options = {})
         indentation = options.key?(:indent) ? options[:indent] : 2
         prefixes = options.key?(:prefixes) ? options[:prefixes] : TO_S_PREFIXES
         DataTablePrinter.new(self, indentation, prefixes).to_s
       end
 
-      class DataTablePrinter # :nodoc:
+      class DataTablePrinter
         include Cucumber::Gherkin::Formatter::Escaping
         attr_reader :data_table, :indentation, :prefixes
         private :data_table, :indentation, :prefixes
@@ -433,7 +435,7 @@ module Cucumber
         end
       end
 
-      def columns # :nodoc:
+      def columns
         @columns ||= cell_matrix.transpose.map do |cell_row|
           Cells.new(self, cell_row)
         end
@@ -456,7 +458,7 @@ module Cucumber
         cells_rows[1..].map(&:to_hash)
       end
 
-      def create_cell_matrix(ast_table) # :nodoc:
+      def create_cell_matrix(ast_table)
         ast_table.raw.map do |raw_row|
           line = begin
             raw_row.line
@@ -469,7 +471,7 @@ module Cucumber
         end
       end
 
-      def convert_columns! # :nodoc:
+      def convert_columns!
         @conversion_procs.each do |column_name, conversion_proc|
           verify_column(column_name) if conversion_proc[:strict]
         end
@@ -483,7 +485,7 @@ module Cucumber
         end
       end
 
-      def convert_headers! # :nodoc:
+      def convert_headers!
         header_cells = cell_matrix[0]
 
         if @header_conversion_proc
@@ -501,12 +503,12 @@ module Cucumber
         end
       end
 
-      def clear_cache! # :nodoc:
+      def clear_cache!
         @hashes = @rows_hash = @column_names = @rows = @columns = nil
       end
 
-      def ensure_table(table_or_array) # :nodoc:
-        return table_or_array if DataTable == table_or_array.class
+      def ensure_table(table_or_array)
+        return table_or_array if table_or_array.instance_of?(DataTable)
 
         DataTable.from(table_or_array)
       end
@@ -516,7 +518,7 @@ module Cucumber
       end
 
       # Represents a row of cells or columns of cells
-      class Cells # :nodoc:
+      class Cells
         include Enumerable
         include Cucumber::Gherkin::Formatter::Escaping
 
@@ -536,21 +538,20 @@ module Cucumber
           nil
         end
 
-        # For testing only
-        def to_sexp # :nodoc:
+        def to_sexp
           [:row, line, *@cells.map(&:to_sexp)]
         end
 
-        def to_hash # :nodoc:
+        def to_hash
           @to_hash ||= @table.cells_to_hash(self)
         end
 
-        def value(n) # :nodoc:
-          self[n].value
+        def value(index)
+          self[index].value
         end
 
-        def [](n)
-          @cells[n]
+        def [](index)
+          @cells[index]
         end
 
         def line
@@ -576,7 +577,7 @@ module Cucumber
         end
       end
 
-      class Cell # :nodoc:
+      class Cell
         attr_reader :line, :table
         attr_accessor :status, :value
 
@@ -591,7 +592,7 @@ module Cucumber
         end
 
         def ==(other)
-          SurplusCell == other.class || value == other.value
+          other.class == SurplusCell || value == other.value
         end
 
         def eql?(other)
@@ -603,12 +604,12 @@ module Cucumber
         end
 
         # For testing only
-        def to_sexp # :nodoc:
+        def to_sexp
           [:cell, @value]
         end
       end
 
-      class SurplusCell < Cell # :nodoc:
+      class SurplusCell < Cell
         def status
           :comment
         end
